export default {
	methods: {
		t,
		n
	},
	data: () => ({
		OC,
		OCA
	})
}
